@@ -48,18 +48,17 @@ has '+widget' => ( default => 'compound' );
 
 sub validate
 {
-    my ( $self ) = @_;
+   my ($self) = @_;
 
-    my @dt_parms;
-    foreach my $child ($self->fields)
-    {
-       next unless $child->value;
-       push @dt_parms, ($child->accessor => $child->value);
-    }
+   my @dt_parms;
+   foreach my $child ( $self->fields ) {
+      next unless $child->value;
+      push @dt_parms, ( $child->accessor => $child->value );
+   }
 
-    # set the value
-    my $dt = DateTime->new(@dt_parms);
-    $self->value($dt);
+   # set the value
+   my $dt = DateTime->new(@dt_parms);
+   $self->value($dt);
 }
 
 __PACKAGE__->meta->make_immutable;
