@@ -29,22 +29,20 @@ For example:
 
 sub validate
 {
-    my ( $self ) = @_;
+   my ($self) = @_;
 
-    my @dur_parms;
-    foreach my $child ($self->fields)
-    {
-       unless ( $child->value =~ /^\d+$/ )
-       {
-          $self->add_error( "Invalid value for " . $self->label . " " . $child->label );
-          next;
-       }
-       push @dur_parms, ($child->accessor => $child->value);
-    }
+   my @dur_parms;
+   foreach my $child ( $self->fields ) {
+      unless ( $child->value =~ /^\d+$/ ) {
+         $self->add_error( "Invalid value for " . $self->label . " " . $child->label );
+         next;
+      }
+      push @dur_parms, ( $child->accessor => $child->value );
+   }
 
-    # set the value
-    my $duration = DateTime::Duration->new(@dur_parms);
-    $self->value($duration);
+   # set the value
+   my $duration = DateTime::Duration->new(@dur_parms);
+   $self->value($duration);
 }
 
 __PACKAGE__->meta->make_immutable;
