@@ -5,14 +5,17 @@ extends 'HTML::FormHandler::Field::Text';
 use Email::Valid;
 our $VERSION = '0.02';
 
-
-apply ([
-   { transform => sub { lc( $_[0] ) } },
-   { check => sub { Email::Valid->address( $_[0] ) },
-     message => ['Email should be of the format [_1]',
-                 'someuser@example.com' ]
-   }
-]);
+apply(
+   [
+      {
+         transform => sub { lc( $_[0] ) }
+      },
+      {
+         check   => sub                                     { Email::Valid->address( $_[0] ) },
+         message => [ 'Email should be of the format [_1]', 'someuser@example.com' ]
+      }
+   ]
+);
 
 =head1 NAME
 
