@@ -90,6 +90,7 @@ has 'options' => (
 );
 sub build_options { [] }
 has 'options_from' => ( isa => 'Str', is => 'rw', default => 'none' );
+has 'loaded_options' => ( isa => 'Bool', is => 'rw', default => 0 );
 
 =head2 set_options
 
@@ -248,8 +249,7 @@ sub as_label
    my $value = $field->value;
    return unless defined $value;
 
-   for ( $field->options )
-   {
+   for ( $field->options ) {
       return $_->{label} if $_->{value} eq $value;
    }
    return;
@@ -259,9 +259,6 @@ sub _inner_validate_field
 {
    my ($self) = @_;
 
-   # load options because this is params validation
-   $self->_load_options;
-
    my $value = $self->value;
    return 1 unless defined $value;    # nothing to check
 
@@ -271,18 +268,15 @@ sub _inner_validate_field
       $self->add_error('This field does not take multiple values');
       return;
    }
-   elsif ( ref $value ne 'ARRAY' && $self->multiple )
-   {
+   elsif ( ref $value ne 'ARRAY' && $self->multiple ) {
       $value = [$value];
       $self->value($value);
    }
 
    # create a lookup hash
    my %options = map { $_->{value} => 1 } $self->options;
-   for my $value ( ref $value eq 'ARRAY' ? @$value : ($value) )
-   {
-      unless ( $options{$value} )
-      {
+   for my $value ( ref $value eq 'ARRAY' ? @$value : ($value) ) {
+      unless ( $options{$value} ) {
          $self->add_error("'$value' is not a valid value");
          return;
       }
@@ -296,7 +290,20 @@ sub _init
 
    $self->SUPER::_init;
    # load options when no input and no value (empty form )
-   $self->_load_options;
+   $self->_load_options unless $self->loaded_options;
+}
+
+# load options for no init_obj && params
+# not in '_inner_validate_field' because that isn't called
+# for fields with no input
+before 'validate_field' => sub {
+   my $self = shift;
+   $self->_load_options unless $self->loaded_options;
+};
+
+sub clear_other
+{
+   shift->loaded_options(0);
 }
 
 sub _load_options
@@ -305,13 +312,11 @@ sub _load_options
 
    return if $self->options_from eq 'build';
    my @options;
-   if ( $self->_can_options )
-   {
+   if ( $self->_can_options ) {
       @options = $self->_options;
       $self->options_from('method');
    }
-   elsif ( $self->form )
-   {
+   elsif ( $self->form ) {
       my $full_accessor;
       $full_accessor = $self->parent->full_accessor if $self->parent;
       @options = $self->form->lookup_options( $self, $full_accessor );
@@ -327,6 +332,7 @@ sub _load_options
    my @opts;
    push @opts, { value => shift @options, label => shift @options } while @options;
    $self->options( \@opts ) if @opts;
+   $self->loaded_options(1);
 }
 
 =head1 AUTHORS
