@@ -7,37 +7,47 @@ our $VERSION = '0.01';
 has 'size' => ( isa => 'Int|Undef', is => 'rw', default => '0' );
 has 'maxlength' => ( isa => 'Int|Undef', is => 'rw' );
 has 'minlength' => ( isa => 'Int|Undef', is => 'rw', default => '0' );
-has 'min_length' => ( isa => 'Int|Undef', is => 'rw', default => '0', reader => '_min_length_r', writer => '_min_length_w' ); # for backcompat
-sub min_length {
-    my ( $self, $value ) = @_;
-    warn "Please use the 'minlength' attribute - 'min_length' is deprecated";
-    if( $value ){
-        $self->_min_length_w($value);
-    }
-    return $self->_min_length_r;
+has 'min_length' => (
+   isa     => 'Int|Undef',
+   is      => 'rw',
+   default => '0',
+   reader  => '_min_length_r',
+   writer  => '_min_length_w'
+);    # for backcompat
+
+sub min_length
+{
+   my ( $self, $value ) = @_;
+   warn "Please use the 'minlength' attribute - 'min_length' is deprecated";
+   if ($value) {
+      $self->_min_length_w($value);
+   }
+   return $self->_min_length_r;
 }
 
 has '+widget' => ( default => 'text' );
 
-sub validate {
-    my $field = shift;
+sub validate
+{
+   my $field = shift;
 
-    return unless $field->SUPER::validate;
-    my $value = $field->input;
-    # Check for max length
-    if ( my $maxlength = $field->maxlength ) {
-        return $field->add_error( 'Please limit to [quant,_1,character]. You submitted [_2]', $maxlength, length $value )
-            if length $value > $maxlength;
-    }
+   return unless $field->SUPER::validate;
+   my $value = $field->input;
+   # Check for max length
+   if ( my $maxlength = $field->maxlength ) {
+      return $field->add_error( 'Please limit to [quant,_1,character]. You submitted [_2]',
+         $maxlength, length $value )
+         if length $value > $maxlength;
+   }
 
-    # Check for min length
-    if ( my $minlength = $field->minlength || $field->_min_length_r ) {
-        return $field->add_error(
-           'Input must be at least [quant,_1,character]. You submitted [_2]',
-           $minlength, length $value )
-            if length $value < $minlength;
-    }
-    return 1;
+   # Check for min length
+   if ( my $minlength = $field->minlength || $field->_min_length_r ) {
+      return $field->add_error(
+         'Input must be at least [quant,_1,character]. You submitted [_2]',
+         $minlength, length $value )
+         if length $value < $minlength;
+   }
+   return 1;
 }
 
 =head1 NAME
