@@ -4,25 +4,21 @@ use Moose;
 extends 'HTML::FormHandler::Field::Select';
 our $VERSION = '0.01';
 
-sub build_options {
-    my $i = 0;
-    my @days = qw/
-        Sunday
-        Monday
-        Tuesday
-        Wednesday
-        Thursday
-        Friday
-        Saturday
-    /;
-    return [
-        map {
-            {   value => $i++, label => $_ }
-        } @days
-    ];
+sub build_options
+{
+   my $i    = 0;
+   my @days = qw/
+      Sunday
+      Monday
+      Tuesday
+      Wednesday
+      Thursday
+      Friday
+      Saturday
+      /;
+   return [ map { { value => $i++, label => $_ } } @days ];
 }
 
-
 =head1 NAME
 
 HTML::FormHandler::Field::Weekday - Select valid day of the week
