@@ -1,4 +1,4 @@
-package  # hide from Pause
+package    # hide from Pause
    HTML::FormHandler::Model::CDBI;
 
 use Moose;
@@ -106,36 +106,30 @@ sub guess_field_type
    my @return;
 
    # Is it a direct has_a relationship?
-   if ( my $meta = $class->meta_info('has_a')->{$column} )
-   {
+   if ( my $meta = $class->meta_info('has_a')->{$column} ) {
       my $f_class = $meta->foreign_class;
 
       @return =
-         $f_class->isa('DateTime')
-         ? ('DateTime')
-         : ( 'Select', $f_class );
+         $f_class->isa('DateTime') ? ('DateTime') :
+                                     ( 'Select', $f_class );
 
       # Otherwise, check for has_many
    }
-   elsif ( $meta = $class->meta_info('has_many')->{$column} )
-   {
+   elsif ( $meta = $class->meta_info('has_many')->{$column} ) {
 
       my $f_class = $meta->foreign_class;
       # Is there a mapping table in between?  If so need to find the
       # actual class for lookups -- call recursively
-      if ( @{ $meta->args->{mapping} } )
-      {
+      if ( @{ $meta->args->{mapping} } ) {
          my $t;
          ( $t, $f_class ) = $self->guess_field_type( $meta->args->{mapping}[0], $f_class );
       }
       @return = ( 'Multiple', $f_class );
    }
-   elsif ( $column =~ /_time$/ )
-   {
+   elsif ( $column =~ /_time$/ ) {
       @return = ('DateTime');
    }
-   else
-   {
+   else {
       @return = ('Text');
    }
 
@@ -186,16 +180,14 @@ sub lookup_options
    return unless $f_class->find_column($label_column);
    # active column
    my $active_col =
-        $self->can('active_column')
-      ? $self->active_column
-      : $field->active_column;
+      $self->can('active_column') ? $self->active_column :
+                                    $field->active_column;
    $active_col = '' unless $f_class->find_column($active_col);
    # sort column
    my $sort_col = $field->sort_column;
    $sort_col =
-      defined $sort_col && $f_class->find_column($sort_col)
-      ? $sort_col
-      : $label_column;
+      defined $sort_col && $f_class->find_column($sort_col) ? $sort_col :
+                                                              $label_column;
 
    my $criteria    = {};
    my $primary_key = $f_class->primary_column;
@@ -206,8 +198,7 @@ sub lookup_options
       if $f_class eq ref $self->item;
 
    # If there's an active column, only select active OR items already selected
-   if ($active_col)
-   {
+   if ($active_col) {
       my @or = ( $active_col => 1 );
       # But also include any existing non-active
       push @or, ( "$primary_key" => $field->init_value )    # init_value is scalar or array ref
@@ -242,20 +233,17 @@ sub init_value
    $item ||= $self->item;
    return if $field->writeonly;
    return
-      unless $item
-         && ( $item->can($column)
-            || ( ref $item eq 'HASH' && exists $item->{$column} ) );
+      unless $item &&
+         ( $item->can($column) ||
+            ( ref $item eq 'HASH' && exists $item->{$column} ) );
    my @values;
-   if ( ref $item eq 'HASH' )
-   {
+   if ( ref $item eq 'HASH' ) {
       @values = $item->{$column} if ref($item) eq 'HASH';
    }
-   elsif ( !$item->isa('Class::DBI') )
-   {
+   elsif ( !$item->isa('Class::DBI') ) {
       @values = $item->$column;
    }
-   else
-   {
+   else {
       @values =
          map { ref $_ && $_->isa('Class::DBI') ? $_->id : $_ } $item->$column;
    }
@@ -300,8 +288,7 @@ sub validate_unique
 
    my $class = ref($item) || $self->item_class;
    my $found_error = 0;
-   for my $field ( map { $self->field($_) } @unique )
-   {
+   for my $field ( map { $self->field($_) } @unique ) {
       next if $field->errors;
       my $value = $field->value;
       next unless defined $value;
@@ -309,8 +296,8 @@ sub validate_unique
       # unique means there can only be on in the database like it.
       my $match = $class->search( { $name => $value } )->first || next;
       next if $self->items_same( $item, $match );
-      my $field_error = $field->unique_message
-         || 'Value must be unique in the database';
+      my $field_error = $field->unique_message ||
+         'Value must be unique in the database';
       $field->add_error($field_error);
       $found_error++;
    }
@@ -332,32 +319,27 @@ sub update_model
    # as that data is directly stored in the object
    my %data;
    # Loads columns (including has_a)
-   foreach my $col ( $class->columns('All') )
-   {
+   foreach my $col ( $class->columns('All') ) {
       next unless exists $fields{$col};
       my $field = delete $fields{$col};
       # If the field is flagged "clear" then set to NULL.
       my $value = $field->value;
-      if ($item)
-      {
+      if ($item) {
          my $cur = $item->$col;
          next unless $value || $cur;
          next if $value && $cur && $value eq $cur;
          $item->$col($value);
       }
-      else
-      {
+      else {
          $data{$col} = $value;
       }
    }
 
-   if ($item)
-   {
+   if ($item) {
       $item->update;
       $updated_or_created = 'updated';
    }
-   else
-   {
+   else {
       $item = $class->create( \%data );
       $self->item($item);
       $updated_or_created = 'created';
@@ -365,8 +347,7 @@ sub update_model
 
    # Now check for mapping/has_many in any left over fields
 
-   for my $field_name ( keys %fields )
-   {
+   for my $field_name ( keys %fields ) {
       next unless $class->meta_info('has_many');
       next unless my $meta = $class->meta_info('has_many')->{$field_name};
 
@@ -386,8 +367,7 @@ sub update_model
          unless $related_key;
 
       # Delete any items that are not to be kept
-      for ( $foreign_class->search( { $foreign_key => $item } ) )
-      {
+      for ( $foreign_class->search( { $foreign_key => $item } ) ) {
          $_->delete unless delete $keep{ $_->$related_key };
       }
 
